Package: alphaOutlier
Type: Package
Title: Obtain Alpha-Outlier Regions for Well-Known Probability
        Distributions
Version: 1.2.2
Date: 2026-04-26
Authors@R: c(person(given = "Andre",
                      family = "Rehage",
                      role = c("aut", "cre"),
                      email = "andre.rehage@gmx.de"),
               person(given = "Sonja",
                      family = "Kuhnt",
                      role = "aut"))
Maintainer: Andre Rehage <andre.rehage@gmx.de>
Description: Given the parameters of a distribution, the package uses the concept of alpha-outliers by Davies and Gather (1993) to flag outliers in a data set. See Davies, L.; Gather, U. (1993): The identification of multiple outliers, JASA, 88 423, 782-792, <doi:10.1080/01621459.1993.10476339> for details.
License: GPL-3
Depends: Rsolnp, nleqslv, quantreg, graphics
Imports: stats
NeedsCompilation: no
Packaged: 2026-04-26 17:00:48 UTC; andrerehage
Author: Andre Rehage [aut, cre],
  Sonja Kuhnt [aut]
Repository: CRAN
Date/Publication: 2026-04-27 06:00:02 UTC
Built: R 4.6.0; ; 2026-05-01 21:26:58 UTC; unix
