Package: alphaOutlier
Type: Package
Title: Obtain Alpha-Outlier Regions for Well-Known Probability
        Distributions
Version: 1.2.0
Date: 2016-09-09
Author: Andre Rehage, Sonja Kuhnt
Maintainer: Andre Rehage <rehage@statistik.tu-dortmund.de>
Description: Given the parameters of a distribution, the package uses the concept of alpha-outliers by Davies and Gather (1993) to flag outliers in a data set. See Davies, L.; Gather, U. (1993): The identification of multiple outliers, JASA, 88 423, 782-792, <doi:10.1080/01621459.1993.10476339> for details.
License: GPL-3
Depends: Rsolnp, nleqslv, quantreg, graphics
Imports: stats
NeedsCompilation: no
Packaged: 2016-09-09 12:55:15 UTC; rehage
Repository: CRAN
Date/Publication: 2016-09-09 18:05:11
Built: R 4.3.3; ; 2025-01-24 14:21:09 UTC; unix
