\name{daysabs}
\docType{data}
\alias{daysabs}
\title{Number of absence days of students}
\description{Number of absence days of students}
\usage{data(daysabs)}
\format{Vector with 314 elements}
\references{http://www.ats.ucla.edu/stat/r/dae/nbreg.htm}
\keyword{datasets}
